@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::Upload 2.67 {
+package Dist::Zilla::Plugin::Author::Plicease::Upload 2.68 {
 
   use 5.020;
   use Moose;
@@ -101,10 +101,13 @@ Dist::Zilla::Plugin::Author::Plicease::Upload - Upload a dist to CPAN
 
 =head1 VERSION
 
-version 2.67
+version 2.68
 
 =head1 SYNOPSIS
 
+ [Author::Plicease::Upload]
+ cpan = 1
+
 =head1 DESCRIPTION
 
 This works similar to L<Dist::Zilla::Plugin::UploadToCPAN>.  Except:
